@@ -5,11 +5,18 @@ from typing import Any, List, Optional, Union
 
 import numpy as np
 import pydicom
+from plotly import graph_objects as go
 from pydicom import FileDataset
 
 from ..helpers.check_path_is_valid import check_path_is_valid_path
+from ..helpers.normalize_dicom_exposure_parameters import get_xray_tube_current_in_ma
 from ..helpers.pixel_data import get_pixel_array
+from ..helpers.rotate_image import rotate_image
 from ..helpers.voxel_data import VoxelData
+from ..helpers.window import get_default_window_settings
+from ..image_quality.variance_image import get_variance_image_2d
+from ..plotting.plotly import show_image
+from ..roi.roi import Roi
 from .dicom_series import DicomSeries
 
 logger = logging.getLogger(__name__)
@@ -95,15 +102,7 @@ class ProjectionSeries(DicomSeries):
             )
 
         self.kV.append(self._get_tag_value_as_float_or_none("KVP", ds=dcm))
-
-        if "XRayTubeCurrent" in dcm:
-            self.mA.append(float(dcm.XRayTubeCurrent))
-        elif "XRayTubeCurrentInmA" in dcm:
-            self.mA.append(float(dcm.XRayTubeCurrentInmA))
-        elif "XRayTubeCurrentInuA" in dcm:
-            self.mA.append(float(dcm.XRayTubeCurrentInuA) / 1000)
-        else:
-            self.mA.append(None)
+        self.mA.append(get_xray_tube_current_in_ma(dcm))
 
         self.ms.append(self._get_tag_value_as_float_or_none("ExposureTime", ds=dcm))
 
@@ -128,26 +127,23 @@ class ProjectionSeries(DicomSeries):
 
         return float(tag_value)
 
-    def import_image(self) -> None:
-        """Import the pixel data into the ImageVolume property
-
-        Returns:
-
-        """
+    def import_image(self, rotate_to_0_degerees: Optional[bool] = False) -> None:
+        """Import the pixel data into the ImageVolume property"""
         self.ImageVolume = []
-        for fp in self.FilePaths:
+        for ind, fp in enumerate(self.FilePaths):
             dcm = pydicom.dcmread(str(fp.absolute()))
-            self.ImageVolume.append(get_pixel_array(dcm=dcm))
+            pixel_array = get_pixel_array(dcm=dcm)
+
+            if rotate_to_0_degerees:
+                pixel_array = rotate_image(image=pixel_array, metadata=self.CompleteMetadata[ind])
+
+            self.ImageVolume.append(pixel_array)
 
         if self.PixelIntensityNormalized:
             self.normalize_pixel_intensity_relationship()
 
     def sort_images_on_acquisition_time(self) -> None:
-        """Reorder the images in the series based on the acquisition time
-
-        Returns:
-
-        """
+        """Reorder the images in the series based on the acquisition time"""
         file_order = [
             ind for ind in list(np.argsort(np.array([self._get_acquisition_time(ds) for ds in self.CompleteMetadata])))
         ]
@@ -161,6 +157,30 @@ class ProjectionSeries(DicomSeries):
         self.FilePaths = self._reorder_list_by_index_order_list(order_list=file_order, list_to_order=self.FilePaths)
         self.ImageVolume = self._reorder_list_by_index_order_list(order_list=file_order, list_to_order=self.ImageVolume)
 
+    def get_variance_images_for_image_volume(self, window_side_x: int = 3, window_side_y: int = 3) -> list[np.ndarray]:
+        """Calculate the variance image for each image in the image volume
+
+        Args:
+            window_side_x: The horizontal side (columns) of the rolling window applied. Default = 3
+            window_side_y: The vertical side (rows) of the rolling window applied. Default = 3
+
+        Returns:
+            A list of variance images in the same order as the images in the ImageVolume
+
+        Raises:
+            ValueError: If the image volume is not imported
+        """
+        if not self.ImageVolume:
+            raise ValueError(
+                f"The image{'s' if len(self.FilePaths) > 1 else ''} must be imported before the variance images can be "
+                f"calculated"
+            )
+
+        return [
+            get_variance_image_2d(image=image, window_side_x=window_side_x, window_side_y=window_side_y)
+            for image in self.ImageVolume
+        ]
+
     @staticmethod
     def _get_acquisition_time(dataset: FileDataset) -> Optional[datetime]:
         acquisition_date = dataset.AcquisitionDate
@@ -179,3 +199,36 @@ class ProjectionSeries(DicomSeries):
         if len(list_to_order) == 0:
             return list_to_order
         return [list_to_order[ind] for ind in order_list]
+
+    def show_image(
+        self,
+        index: int = 0,
+        rois: Optional[Roi] = None,
+        colour_map: str = "bone",
+        window: Optional[tuple[float, float]] = None,
+        roi_only_borders: Optional[bool] = True,
+        roi_colour: str = "#33a652",
+        roi_border_width: int = 2,
+    ) -> go.Figure:
+        super().show_image(index=index, rois=rois, colour_map=colour_map, window=window)
+
+        if self.ImageVolume is None:
+            self.import_image()
+
+        if window is None:
+            window = self._get_default_window_settings(index=index)
+
+        return show_image(
+            image=self.ImageVolume[index],
+            x_scale=self.VoxelData[index].x,
+            y_scale=self.VoxelData[index].y,
+            window=window,
+            rois=rois,
+            roi_colour=roi_colour,
+            roi_only_border=roi_only_borders,
+            roi_border_width=roi_border_width,
+            colour_map=colour_map,
+        )
+
+    def _get_default_window_settings(self, index: int) -> tuple[float, float]:
+        return get_default_window_settings(metadata=self.CompleteMetadata[index], image_slice=self.ImageVolume[index])
